summaryrefslogtreecommitdiff
path: root/src/fileselect.S
diff options
context:
space:
mode:
authorTreeki <treeki@gmail.com>2012-10-08 05:37:19 +0200
committerTreeki <treeki@gmail.com>2012-10-08 05:37:19 +0200
commitd95bd02a18814ad629cf5fc7fb60449f2ba7a418 (patch)
tree7f9ae63739abf904b6533c5a8161c29cac05980f /src/fileselect.S
parent196cbc2f41b72dea9b228815eb61d90a988c817d (diff)
downloadkamek-d95bd02a18814ad629cf5fc7fb60449f2ba7a418.tar.gz
kamek-d95bd02a18814ad629cf5fc7fb60449f2ba7a418.zip
skawo can go fuck himself with a rake
Diffstat (limited to 'src/fileselect.S')
-rw-r--r--src/fileselect.S18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/fileselect.S b/src/fileselect.S
index a10a474..38874cc 100644
--- a/src/fileselect.S
+++ b/src/fileselect.S
@@ -77,7 +77,7 @@ DFNiceWorldName:
ori r4, r4, ConvertedWorldName@l
mr r3, r4
mr r5, r31
- li r6, 36
+ li r6, 32
mtctr r6
convWNameLoop:
lbz r6, 0x6FC(r5)
@@ -94,20 +94,20 @@ convWNameLoop:
bctrl
# now set the colours
- # Text colours: 0x720, hint colours: 0x728
- lwz r3, 0x720(r31)
+ # Text colours: 0x71C, hint colours: 0x724
+ lwz r3, 0x71C(r31)
stw r3, 0xDC(r20)
- lwz r3, 0x724(r31)
+ lwz r3, 0x720(r31)
stw r3, 0xE0(r20)
addi r3, r30, 0x74
lis r4, Picture_00@h
ori r4, r4, Picture_00@l
bl findPictureByName__Q23m2d17EmbedLayoutBase_cCFPCc
- lwz r4, 0x728(r31)
+ lwz r4, 0x724(r31)
stw r4, 0xD8(r3)
stw r4, 0xDC(r3)
- lwz r4, 0x72C(r31)
+ lwz r4, 0x728(r31)
stw r4, 0xE0(r3)
stw r4, 0xE4(r3)
@@ -342,20 +342,20 @@ DFTitle:
ConvertedWorldName:
.short 0,0,0,0,0,0,0,0,0,0,0,0 # 12
.short 0,0,0,0,0,0,0,0,0,0,0,0 # 12
-.short 0,0,0,0,0,0,0,0,0,0,0,0 # 12
+.short 0,0,0,0,0,0,0,0 # 8
.align 4
DefaultSavefileInfoData:
.string "Yoshi's Island" #15
.byte 0,0,0,0,0,0,0,0,0,0,0 # 11
-.byte 0,0,0,0,0,0,0,0,0,0 # 10
+.byte 0,0,0,0,0,0 # 6
.long 0xFFFF99FF,0x1FB423FF
.long 0x173714FF,0x3C9135FF
.long 0xFFFF99FF,0x1FB423FF
.short 0x75
.byte 0x2E,0xB
.byte 0,1
-.byte 0,0
+.byte 0,10
DefaultSavefileInfoDataEnd:
.long 0